import QtQuick 1.0
import quickwidgets 1.0
import "request.js" as API

Rectangle {

    property bool getcover: true
    color: "black"
    border { color: "#606060"; width: 1}
    radius: 5
    width: 300
    height: 200
    property int refreshTime: 5000

    function reset() {
        artist.text = "";
        if (song.text != "Quick Lyrics")
            song.text = "Quick Lyrics"
        if (cover.source !="http://www.chartlyrics.com/img/logo.png")
            cover.source = "http://www.chartlyrics.com/img/logo.png"
        txt.text = " "
    }
    signal songChanged(string t, string a)
    function setData(lyric, img, art, sng) {
        console.debug("data set")
        txt.text = lyric
        if (getcover) {
            cover.source = img
        } else {
            cover.source = ""
        }

        artist.text = art
        song.text = sng
    }

    RotText {
        id: song
        side: "left"
        text: "Quick Lyrics"
    }
    RotText {
        id: artist
        side: "right"
        Component.onCompleted: { console.log(artist.width, artist.height) }
    }

    Image {
        id: cover
        width: Math.min(parent.height, parent.width)-40
        anchors.centerIn: parent
        source: "http://www.chartlyrics.com/img/logo.png"
        fillMode: Image.PreserveAspectFit
        Rectangle {
            anchors.centerIn:  parent
            width: parent.paintedWidth
            height: parent.paintedHeight
            color: "black"
            opacity: 0.6
        }
    }

    ScrollBox {
        id: txt
        scrollDuration:  10000
        height: 200
        fontSize: 11
        // use height here as the text is rotated
        width: parent.width-artist.boxWidth-song.boxWidth
        anchors {
            fill: parent
            rightMargin: artist.boxWidth + 5;
            leftMargin: song.boxWidth + 5;
            topMargin: 10
            bottomMargin: 10
        }
        text: ""
        color: "transparent"
        textColor: "white"
    }

    Timer {
        onTriggered: {
            //API.doRequest("U2", "Sunday Bloody Sunday", setData)
            metadata.run()
        }
        interval:  refreshTime
        running: runtime.isActiveWindow
        triggeredOnStart: true
        repeat: true
    }

    Process {
        function parseAndCall(stdout) {
            var rx = /"([\S\s]*?)"/;
            var val=stdout.match(rx)
            if (val) {
                var parts = val[1].split("\n");
                console.log(parts)
                if (parts.length == 3) {
                    API.doRequest(parts[1], parts[0], setData)
                }
             }
        }

        id: metadata
        command: "dbus-send --type=method_call --print-reply --dest=ru.somebody.someplayer / ru.somebody.someplayer.title_artist_album"
        onCompleted: {parseAndCall(stdout)}
        onFailed: { reset() }
    }

    Component.onCompleted: {
        //reset()
        //API.doRequest("Alice in Chains", "Them Bones", setData)
    }
}
